@@ -11,6 +11,7 @@
 
 __all__ = ['PyomoMIPConverter']
 
+import coopr.pyomo
 from coopr.opt.base import *
 from pico import PicoMIPConverter
 
@@ -19,6 +20,7 @@ from pyutilib.component.config import *
 from pyutilib.component.executables import *
 import pyutilib.services
 
+
 class PyomoMIPConverter(ManagedSingletonPlugin):
 
     implements(IProblemConverter)
@@ -38,7 +40,7 @@ class PyomoMIPConverter(ManagedSingletonPlugin):
             return True
         if from_type == ProblemFormat.pyomo and to_type == ProblemFormat.cpxlp:
             return True
-        if from_type == ProblemFormat.pyomo and to_type == ProblemFormat.mps:
+        if self.pico_converter.available() and from_type == ProblemFormat.pyomo and to_type == ProblemFormat.mps:
             return True
         return False
 
@@ -48,19 +50,42 @@ class PyomoMIPConverter(ManagedSingletonPlugin):
         conversions.
         """
 
+        if isinstance(args[2], basestring):
+            instance = None
+        else:
+            instance = args[2]
+        #elif isinstance(args[2], coopr.pyomo.Model):
+            #instance = args[2]
+        #else:
+            #raise IOError, "Bad data type for conversion: %s" % str(type(args[2]))
+
         if args[1] is ProblemFormat.cpxlp:
             problem_filename = pyutilib.services.TempfileManager.create_tempfile(suffix = '.pyomo.lp')
-            (problem_filename, varmap) = args[2].write(filename=problem_filename,format=ProblemFormat.cpxlp)
-            return (problem_filename,),None # no map file is necessary
-        elif args[1] is ProblemFormat.mps:
-            # TBD: We don't support a variable map file when going from NL to MPS within the PICO converter.
+            if instance:
+                (problem_filename, varmap) = instance.write(filename=problem_filename,format=ProblemFormat.cpxlp)
+                return (problem_filename,),None # no map file is necessary
+            else:
+                model = coopr.pyomo.scripting.pyomo2lp(['--save-model',problem_filename,args[2]])
+                return (model.filename,),model.symbol_map
+
+        elif args[1] in [ProblemFormat.mps, ProblemFormat.nl]:
             problem_filename = pyutilib.services.TempfileManager.create_tempfile(suffix = '.pyomo.nl')
-            (problem_filename, varmap) = args[2].write(filename=problem_filename,format=ProblemFormat.nl)
+            if instance:
+                (problem_filename, varmap) = instance.write(filename=problem_filename,format=ProblemFormat.nl)
+            else:
+                model = coopr.pyomo.scripting.pyomo2nl(['--save-model',problem_filename,args[2]])
+                problem_filename = model.filename
+                varmap = model.symbol_map
+            if args[1] is ProblemFormat.nl:
+                return (problem_filename,),varmap
+            #
+            # Convert from NL to MPS
+            # 
+            # TBD: We don't support a variable map file when going from NL to MPS within the PICO converter.
+            # NOTE: this is a problem with the MPS writer that is provided by COIN-OR
+            # NOTE: we should generalize this so it doesn't strictly depend on the PICO converter utility.
+            #
             ans = self.pico_converter.apply(ProblemFormat.nl,ProblemFormat.mps,problem_filename)
             os.remove(problem_filename)
             return ans
-        elif args[1] is ProblemFormat.nl:
-            problem_filename = pyutilib.services.TempfileManager.create_tempfile(suffix = '.pyomo.nl')
-            (problem_filename, symbol_map) = args[2].write(filename=problem_filename,format=ProblemFormat.nl)
-            return (problem_filename,),symbol_map # map file is necessary
 
