@@ -11,13 +11,10 @@
 
 __all__ = []
 
-import pyutilib.misc
-import pyutilib.component.core
-from coopr.opt.parallel.manager import *
-from coopr.opt.parallel.solver import *
-from coopr.opt.results import SolverResults
-
-import pickle
+try:
+    import cPickle as pickle
+except ImportError:
+    import pickle
 
 try:
     import Pyro.core
@@ -25,7 +22,12 @@ try:
     using_pyro=True
 except ImportError:
     using_pyro=False
-        
+
+import pyutilib.misc
+import pyutilib.component.core
+from coopr.opt.parallel.manager import *
+from coopr.opt.parallel.solver import *
+from coopr.opt.results import SolverResults
 
 class SolverManager_Pyro(AsynchronousSolverManager):
 
@@ -86,7 +88,7 @@ class SolverManager_Pyro(AsynchronousSolverManager):
         data=pyutilib.misc.Bunch(opt=self._opt.type, \
                                  file=problem_file_string, filename=self._opt._problem_files[0], \
                                  warmstart_file=warm_start_file_string, warmstart_filename=warm_start_file_name, \
-                                 kwds=kwds, solver_options=solver_options, mipgap=self._opt.mipgap)
+                                 kwds=kwds, solver_options=solver_options, mipgap=self._opt.mipgap, suffixes=self._opt.suffixes)
         task = pyutilib.pyro.Task(data=data, id=ah.id)
         self.client.add_task(task)
         self._ah[task.id] = ah
